IoT Hub ESP32 AirLift Networking
--------------------------------

Ensure your IoT Hub device works with this simple test.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_hub_simpletest.py
    :caption: examples/azureiot_esp32spi/azureiot_hub_simpletest.py
    :linenos:

Handle direct methods.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_hub_directmethods.py
    :caption: examples/azureiot_esp32spi/azureiot_hub_directmethods.py
    :linenos:

Send device to cloud messages, and handle cloud to device messages.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_hub_messages.py
    :caption: examples/azureiot_esp32spi/azureiot_hub_messages.py
    :linenos:

Update the reported properties of the devices device twin, and receive updates to desired properties.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_hub_twin_operations.py
    :caption: examples/azureiot_esp32spi/azureiot_hub_twin_operations.py
    :linenos:

IoT Central ESP32 AirLift Networking
------------------------------------

Ensure your IoT Central device works with this simple test.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_central_simpletest.py
    :caption: examples/azureiot_esp32spi/azureiot_central_simpletest.py
    :linenos:

Handle commands.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_central_commands.py
    :caption: examples/azureiot_esp32spi/azureiot_central_commands.py
    :linenos:

Update the properties of the device, and receive updates to properties.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_central_properties.py
    :caption: examples/azureiot_esp32spi/azureiot_central_properties.py
    :linenos:

Handle connection errors.

.. literalinclude:: ../examples/azureiot_esp32spi/azureiot_central_notconnected.py
    :caption: examples/azureiot_esp32spi/azureiot_central_notconnected.py
    :linenos:

IoT Hub Native Networking
-------------------------

Ensure your IoT Hub device works with this simple test.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_hub_simpletest.py
    :caption: examples/azureiot_native_networking/azureiot_hub_simpletest.py
    :linenos:

Handle direct methods.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_hub_directmethods.py
    :caption: examples/azureiot_native_networking/azureiot_hub_directmethods.py
    :linenos:

Send device to cloud messages, and handle cloud to device messages.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_hub_messages.py
    :caption: examples/azureiot_native_networking/azureiot_hub_messages.py
    :linenos:

Update the reported properties of the devices device twin, and receive updates to desired properties.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_hub_twin_operations.py
    :caption: examples/azureiot_native_networking/azureiot_hub_twin_operations.py
    :linenos:

IoT Central Native Networking
-----------------------------

Ensure your IoT Central device works with this simple test.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_central_simpletest.py
    :caption: examples/azureiot_native_networking/azureiot_central_simpletest.py
    :linenos:

Handle commands.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_central_commands.py
    :caption: examples/azureiot_native_networking/azureiot_central_commands.py
    :linenos:

Update the properties of the device, and receive updates to properties.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_central_properties.py
    :caption: examples/azureiot_native_networking/azureiot_central_properties.py
    :linenos:

Handle connection errors.

.. literalinclude:: ../examples/azureiot_native_networking/azureiot_central_notconnected.py
    :caption: examples/azureiot_native_networking/azureiot_central_notconnected.py
    :linenos:
